<?php

/*
 * ******************************************************************************
 * File name: utilities.function.php
 * Created on: 20/06/2008
 * ******************************************************************************
  -----------------
  -- Description --
  -----------------
  This file has all the functions which are to be used in various modules.

  -----------------------------------------
  -- Major Revision/Modification History --
  -----------------------------------------
  Date			    Programmer			  Comments
  ----------		---------------		---------------------------------
  20/06/2008		Anish Sharma		  Started building the file.

 * ******************************************************************************
 *  Written By: Anish Sharma.
 * ******************************************************************************
 */
include_once("tables.php");

/**
 * This function checks for the valid email id.
 * @param	string.
 * @return	1 or 0.
 * @author	Anish Sharma
 */
function isValidEmail($email) {
	if (eregi("^[_a-z0-9-]+(\.[_a-z0-9-]+)*@[a-z0-9-]+(\.[a-z0-9-]+)*(\.[a-z]{2,3})$", $email)) {
		return (1);
	}
	return (0);
}

/**
 * This function works in the same way as PHP's trim.
 * @param	string.
 * @return	string.
 * @author	Anish Sharma
 */
function removeSpaces($var) {
	return(trim($var) != '');
}

/**
 * This function returns all the info for the user.
 * @param	string.
 * @return	string.
 * @author	Anish Sharma
 */
function validUser($_CONF = false) {
	if (isset($_SESSION['session_userId']) && $_SESSION['session_userId'] != '') {
		return true;
	} else {
		reDirect($_CONF['siteUrl'] . 'login.php');
		exit();
	}
}

/**
 * This function returns all the info for the user.
 * @param	string.
 * @return	string.
 * @author	Anish Sharma
 */
function getUserById($id, $db = '') {
	if (!is_object($db)) {
		makeDbConnection($db);
	}
	$userData = array();
	$query = "SELECT * FROM tbl_users where uId='{$id}'";
	$Res = $db->execQry($query);
	$Rows = $db->rowCount($Res);
	if ($Rows > 0) {
		$userData = $db->fetchRow($Res);
	}
	return $userData;
}

/**
 * This function works in the same way as PHP's header.
 * @param	string.
 * @return	string.
 * @author	Anish Sharma
 */
function reDirect($reDirectTo, $exit = true) {
	if (trim($reDirectTo) != '') {
		header('location: ' . $reDirectTo);
		if ($exit) {
			exit;
		}
	}
}

/**
 * This function works in the same way as PHP's stripslashes.
 * @param	string.
 * @return	string.
 * @author	Anish Sharma
 */
function fn_stripslash($value) {
	$value = stripslashes($value);
	return $value;
}

/**
 * This function works in the same way as PHP's ucfirst.(Make a string's first character uppercase)
 * @param	string.
 * @return	string.
 * @author	Anish Sharma
 */
function firstUpper($value) {
	$value = ucfirst($value);
	return $value;
}

/**
 * This function works in the same way as PHP's htmlentities.
 * @param	string.
 * @return	string.
 * @author	Anish Sharma
 */
function html_entities($value) {
	$value = htmlentities(fn_stripslash($value));
	return $value;
}

/**
 * This function works in the same way as PHP's addslashes.
 * @param	string.
 * @return	string.
 * @author	Anish Sharma
 */
function fn_addslash($value) {
	$value = addslashes($value);
	return $value;
}

/**
 * This function works in the same way as PHP's htmlspecialchars.
 * @param	string.
 * @return	string.
 * @author	Anish Sharma
 */
function html_specialchar($value) {
	$value = htmlspecialchars(fn_stripslash($value));
	return $value;
}

/**
 * This function will make the DB connection.
 * @param	string.
 * @return	string.
 * @author	Anish Sharma
 */
function makeDbConnection(&$db) {
	global $dbUser, $dbPassword, $dataBase;
	$db = new database();
	$db->db_user = $dbUser;
	$db->db_password = $dbPassword;
	$db->db_name = $dataBase;
}

/**
 * This function will return all the countries.
 * @param	string.
 * @return	string.
 * @author	Anish Sharma
 */
function countryList($countryId = '', $db = '') {
	$arrString = '';
	if (!is_object($db)) {
		makeDbConnection($db);
	}
	$query = "SELECT cId,cName,cCode FROM " . TABLECOUNTRY . " WHERE status=1";
	$Res = $db->execQry($query);
	$Rows = $db->rowCount($Res);
	if ($Rows > 0) {
		while ($rowData = $db->fetchObj($Res)) {
			$selected = ($rowData->cId == $countryId) ? 'selected="selected"' : '';
			$arrString.= '<option value="' . $rowData->cId . '" ' . $selected . '>' . $rowData->cName . '</option>';
		}
	}
	return $arrString;
}

/**
 * This function will return all the case status.
 * @param	string.
 * @return	string.
 * @author	Anish Sharma
 */
function caseStatusList($csId = '', $flag = '', $db = '', $chPlan = false) {
	$arrString = '';
	if (!is_object($db)) {
		makeDbConnection($db);
	}
	$query = "SELECT csId,csName FROM " . TABLECASESTATUS . " WHERE status=1";
	$Res = $db->execQry($query);
	$Rows = $db->rowCount($Res);
	if ($Rows > 0) {
		if ($flag == 0) {
			$arrString.= '<option value="0">In Progress</option>';
		} else if ($flag == 1) {
			$arrString.= '<option value="0" selected>In Progress</option>';
		}
		while ($rowData = $db->fetchObj($Res)) {
			if ($chPlan) {
				$selected = ($rowData->csId == $csId) ? 'selected="selected"' : '';
				$arrString.= '<option value="' . $rowData->csId . '" ' . $selected . '>' . $rowData->csName . '</option>';
			} else {
				if ($rowData->csId != 6 && $rowData->csId != 7) {
					$selected = ($rowData->csId == $csId) ? 'selected="selected"' : '';
					$arrString.= '<option value="' . $rowData->csId . '" ' . $selected . '>' . $rowData->csName . '</option>';
				}
			}
		}
	}
	return $arrString;
}

/**
 * This function will return all the countries.
 * @param	string.
 * @return	string.
 * @author	Anish Sharma
 */
function menuList($mId = '', $db = '') {
	$arrString = '';
	if (!is_array($mId)) {
		$mid = explode(',', $mId);
	} else {
		$mid = $mId;
	}
	if (!is_object($db)) {
		makeDbConnection($db);
	}
	$query = "SELECT mId,mName FROM " . TABLEMENU . " WHERE mPrId = 0 AND mName != 'Home' AND mName !='Log Out'";
	$Res = $db->execQry($query);
	$Rows = $db->rowCount($Res);
	if ($Rows > 0) {
		$arrString .= '<table border="0" class="chkbox" width="100%" cellspacing="0" cellpadding="0">';
		while ($rowData = $db->fetchObj($Res)) {
			$checked = (in_array($rowData->mId, $mid)) ? 'checked="checked"' : '';
			$arrString .= '<tr><td><input type="checkbox" name="menuChk[]" id="' . $rowData->mId . '" value="' . $rowData->mId . '" ' . $checked . ' /><label for="' . $rowData->mId . '">' . $rowData->mName . '</label></td></tr>';
		}
		$arrString .= '</table>';
	}
	return $arrString;
}

/**
 * This function will return all the countries.
 * @param	string.
 * @return	string.
 * @author	Anish Sharma
 */
function getMenuLinks($utId = '', $db = '') {
	$arrString = '';
	if (!is_object($db)) {
		makeDbConnection($db);
	}
	$query = "SELECT mId, mName, mHasChild, mLink FROM " . TABLEMENU . " WHERE FIND_IN_SET(mId, (SELECT urMenuId FROM " . TABLEUSERRIGHTS . " WHERE urUserTypeId = " . $utId . "))";
	$Res = $db->execQry($query);
	$Rows = $db->rowCount($Res);
	if ($Rows > 0) {
		$arrString .= '<ul class="sf-menu">';
		$arrString .='<li><a href="index.php">Home</a></li>';
		while ($rowData = $db->fetchObj($Res)) {
			$arrString .= '<li><a href="' . $rowData->mLink . '">' . $rowData->mName . '</a>';
			$arrSub = '';
			if ($rowData->mHasChild == 1) {
				$qrySub = "SELECT mPrId,mName,mLink FROM tbl_menu WHERE mPrId=" . $rowData->mId;
				$res = $db->execQry($qrySub);
				$rows = $db->rowCount($res);
				if ($rows > 0) {
					$arrSub .= '<ul>';
					while ($rowSub = $db->fetchObj($res)) {
						$arrSub .= '<li><a href="' . $rowSub->mLink . '">' . $rowSub->mName . '</a></li>';
					}
					$arrSub .='</ul>';
				}
			}

			$arrString .= $arrSub . '</li>';
		}
		//$arrString .='<li><a href="old/logintomis.php" target="_blank">Prev. System</a></li>';
		$arrString .='<li><a href="logout.php">Log Out</a></li>';
		$arrString .='</ul>';
		return $arrString;
	}
}

/**
 * This function will return all the user types.
 * @param	string.
 * @return	string.
 * @author	Anish Sharma
 */
function userTypeList($uId = '', $db = '') {
	$arrString = '';
	if (!is_object($db)) {
		makeDbConnection($db);
	}
	$query = "SELECT utId,utName FROM " . TABLEUSERTYPE . " WHERE status=1";
	$Res = $db->execQry($query);
	$Rows = $db->rowCount($Res);
	if ($Rows > 0) {
		while ($rowData = $db->fetchObj($Res)) {
			$selected = ($rowData->utId == $uId) ? 'selected="selected"' : '';
			$arrString.= '<option value="' . $rowData->utId . '" ' . $selected . '>' . $rowData->utName . '</option>';
		}
	}
	return $arrString;
}

/**
 * This function will return all the service countries.
 * @param	string.
 * @return	string.
 * @author	Anish Sharma
 */
function serviceCountryList($countryId = '', $db = '') {
	$arrString = '';
	if (!is_object($db)) {
		makeDbConnection($db);
	}
	$query = "SELECT scId,scCountryId,scCountryAutoId FROM " . TABLESERVICECOUNTRY . " WHERE status=1";
	$Res = $db->execQry($query);
	$Rows = $db->rowCount($Res);
	if ($Rows > 0) {
		while ($rowData = $db->fetchObj($Res)) {
			$selected = ($rowData->scId == $countryId) ? 'selected="selected"' : '';
			$arrString.= '<option value="' . $rowData->scId . '" ' . $selected . '>' . getCountryName($rowData->scCountryId) . '</option>';
		}
	}
	return $arrString;
}

/**
 * This function will return all the service types.
 * @param	string.
 * @return	string.
 * @author	Anish Sharma
 */
function serviceTypeList($serviceTypeId = '', $db = '') {
	$arrString = '';
	if (!is_object($db)) {
		makeDbConnection($db);
	}
	$query = "SELECT stId,stName,stCode FROM " . TABLESERVICETYPE . " WHERE status=1";
	$Res = $db->execQry($query);
	$Rows = $db->rowCount($Res);
	if ($Rows > 0) {
		while ($rowData = $db->fetchObj($Res)) {
			$selected = ($rowData->stId == $serviceTypeId) ? 'selected="selected"' : '';
			$arrString.= '<option value="' . $rowData->stId . '" ' . $selected . '>' . $rowData->stName . '</option>';
		}
	}
	return $arrString;
}

/**
 * This function will return the country's name.
 * @param	string.
 * @return	string.
 * @author	Anish Sharma
 */
function getCountryName($countryId = '', $db = '') {
	$cName = '';
	if (!is_object($db)) {
		makeDbConnection($db);
	}
	$query = "SELECT cName FROM " . TABLECOUNTRY . " WHERE cId={$countryId}";
	$Res = $db->execQry($query);
	$Rows = $db->rowCount($Res);
	$rowData = $db->fetchObj($Res);
	if ($Rows > 0) {
		$cName = $rowData->cName;
	}
	return $cName;
}

/**
 * This function will return the user type's name.
 * @param	string.
 * @return	string.
 * @author	Anish Sharma
 */
function getUserType($utId = '', $db = '') {
	$utName = '';
	if (!is_object($db)) {
		makeDbConnection($db);
	}
	$query = "SELECT utName FROM " . TABLEUSERTYPE . " WHERE utId={$utId}";
	$Res = $db->execQry($query);
	$Rows = $db->rowCount($Res);
	$rowData = $db->fetchObj($Res);
	if ($Rows > 0) {
		$utName = firstUpper($rowData->utName);
	}
	return $utName;
}

/**
 * This function will return the branch's name.
 * @param	string.
 * @return	string.
 * @author	Anish Sharma
 */
function getBranchName($bId = '', $db = '') {
	$bName = '';
	if (!is_object($db)) {
		makeDbConnection($db);
	}
	$query = "SELECT bName FROM " . TABLEBRANCH . " WHERE bId={$bId}";
	$Res = $db->execQry($query);
	$Rows = $db->rowCount($Res);
	$rowData = $db->fetchObj($Res);
	if ($Rows > 0) {
		$bName = firstUpper($rowData->bName);
	}
	return $bName;
}


function getGSTIN($bId = '', $db = '') {
	$bName = '';
	if (!is_object($db)) {
		makeDbConnection($db);
	}
	$query = "SELECT bGSTIN FROM " . TABLEBRANCH . " WHERE bId={$bId}";
	$Res = $db->execQry($query);
	$Rows = $db->rowCount($Res);
	$rowData = $db->fetchObj($Res);
	if ($Rows > 0) {
		$bGSTIN = $rowData->bGSTIN;
	}
	return $bGSTIN;
}
/**
 * This function will return the currency name.
 * @param	string.
 * @return	string.
 * @author	Anju Kansal
 */
function getCurrName($currId = '', $db = '') {
	$currName = '';
	if (!is_object($db)) {
		makeDbConnection($db);
	}
	$query = "SELECT curName FROM " . TABLECURRENCY . " WHERE curId={$currId}";
	$Res = $db->execQry($query);
	$Rows = $db->rowCount($Res);
	$rowData = $db->fetchObj($Res);
	if ($Rows > 0) {
		$currName = firstUpper($rowData->curName);
	}
	return $currName;
}

/**
 * This function will return the branch manager's name.
 * @param	string.
 * @return	string.
 * @author	Anish Sharma
 */
function getBranchManagerName($bId = '', $db = '') {
	$bManagerName = '';
	if (!is_object($db)) {
		makeDbConnection($db);
	}
	$query = "SELECT bManagerName FROM " . TABLEBRANCH . " WHERE bId={$bId}";
	$Res = $db->execQry($query);
	$Rows = $db->rowCount($Res);
	$rowData = $db->fetchObj($Res);
	if ($Rows > 0) {
		$bManagerName = $rowData->bManagerName;
	}
	return $bManagerName;
}

/**
 * This function will return the installment's name.
 * @param	string.
 * @return	string.
 * @author	Anish Sharma
 */
function getInstallmentName($instId = '', $db = '') {
	$instName = '';
	if (!is_object($db)) {
		makeDbConnection($db);
	}
	$query = "SELECT iName FROM " . TABLEINSTALLMENT . " WHERE iId={$instId}";
	$Res = $db->execQry($query);
	$Rows = $db->rowCount($Res);
	$rowData = $db->fetchObj($Res);
	if ($Rows > 0) {
		$instName = $rowData->iName;
	}
	return $instName;
}

/**
 * This function will return the advisor's name.
 * @param	string.
 * @return	string.
 * @author	Anish Sharma
 */
function getAdvisorName($advId = '', $db = '') {
	$advName = '';
	if (!is_object($db)) {
		makeDbConnection($db);
	}
	$query = "SELECT adName FROM " . TABLEADVISOR . " WHERE adId={$advId}";
	$Res = $db->execQry($query);
	$Rows = $db->rowCount($Res);
	$rowData = $db->fetchObj($Res);
	if ($Rows > 0) {
		$advName = $rowData->adName;
	}
	return $advName;
}

/**
 * This function will return the case status name.
 * @param	string.
 * @return	string.
 * @author	Anish Sharma
 */
function getCaseStatusName($csId = '', $db = '') {
	$csName = '';
	if (!is_object($db)) {
		makeDbConnection($db);
	}
	if ($csId == 0) {
		$csName = 'In Progress';
	} else {
		$query = "SELECT csName FROM " . TABLECASESTATUS . " WHERE csId={$csId}";
		$Res = $db->execQry($query);
		$Rows = $db->rowCount($Res);
		$rowData = $db->fetchObj($Res);
		if ($Rows > 0) {
			$csName = $rowData->csName;
		}
	}
	return $csName;
}

/**
 * This function will return the branch's name.
 * @param	string.
 * @return	string.
 * @author	Anish Sharma
 */
function getConsultancyName($ctId = '', $db = '') {
	$ctName = '';
	if (!is_object($db)) {
		makeDbConnection($db);
	}
	$query = "SELECT ctName FROM " . TABLECONSULTANCYTYPE . " WHERE ctId={$ctId}";
	$Res = $db->execQry($query);
	$Rows = $db->rowCount($Res);
	if ($Rows > 0) {
		$rowData = $db->fetchObj($Res);
		$ctName = $rowData->ctName;
	}
	return $ctName;
}

/**
 * This function will return the mutiple branch names.
 * @param	string.
 * @return	string.
 * @author	Anish Sharma
 */
function getMutipleBranchName($bId = '', $db = '') {
	$bName = '';
	if (!is_object($db)) {
		makeDbConnection($db);
	}
	$query = "SELECT bName FROM " . TABLEBRANCH . " WHERE bId IN ({$bId})";
	$Res = $db->execQry($query);
	$Rows = $db->rowCount($Res);
	if ($Rows > 0) {
		while ($rowData = $db->fetchObj($Res)) {
			$bName .= $rowData->bName . '<br>';
		}
		return $bName;
	}
}

/**
 * This function will return the mutiple menus names.
 * @param	string.
 * @return	string.
 * @author	Anish Sharma
 */
function getMenuName($mId = '', $db = '') {
	$mName = '';
	if (!is_object($db)) {
		makeDbConnection($db);
	}
	$query = "SELECT mName FROM " . TABLEMENU . " WHERE mId IN ({$mId})";
	$Res = $db->execQry($query);
	$Rows = $db->rowCount($Res);
	if ($Rows > 0) {
		while ($rowData = $db->fetchObj($Res)) {
			$mName .= $rowData->mName . '<br>';
		}
		return $mName;
	}
}

/**
 * This function will return the country's code.
 * @param	string.
 * @return	string.
 * @author	Anish Sharma
 */
function getCountryCode($countryId = '', $db = '') {
	$cCode = '';
	if (!is_object($db)) {
		makeDbConnection($db);
	}
	$query = "SELECT cCode FROM " . TABLECOUNTRY . " WHERE cId={$countryId}";
	$Res = $db->execQry($query);
	$Rows = $db->rowCount($Res);
	$rowData = $db->fetchObj($Res);
	$cCode = $rowData->cCode;
	return $cCode;
}

/**
 * This function will return the currency code respective to the country's id.
 * @param	string.
 * @return	string.
 * @author	Anish Sharma
 */
function getCurrCode($cId = '', $db = '') {
	$currCode[] = '';
	if (!is_object($db)) {
		makeDbConnection($db);
	}
	$query = "SELECT curId,curSymbol FROM " . TABLECURRENCY . " WHERE curCId={$cId}";
	$Res = $db->execQry($query);
	$Rows = $db->rowCount($Res);
	$rowData = $db->fetchObj($Res);
	$currCode = $rowData->curSymbol . ',' . $rowData->curId;
	return $currCode;
}

/**
 * This function will return the currency code respective to the country's id.
 * @param	string.
 * @return	string.
 * @author	Anish Sharma
 */
function getNewCurrCode($cId = '', $db = '') {
	$currCode[] = '';
	if (!is_object($db)) {
		makeDbConnection($db);
	}

	//$query = "SELECT curId,curSymbol FROM ".TABLECURRENCY." WHERE curCId={$cId}";
	if (is_array($cId)) {
		$cid = implode(',', $cId);
	} else {
		$cid = $cId;
	}

	$query = "SELECT curId,curSymbol FROM tbl_currency WHERE curCId IN (SELECT bCid FROM tbl_branch WHERE bId IN ({$cid}) GROUP BY bCid) AND status=1";

	$Res = $db->execQry($query);
	$Rows = $db->rowCount($Res);
	$rowData = $db->fetchObj($Res);
	$currCode = $rowData->curSymbol . ',' . $rowData->curId;
	return $currCode;
}

/**
 * This function will generate a random password/number of the specified length.
 * @param	string.
 * @return	string.
 * @author	Anish Sharma
 */
function genPwd($len = '') {
	$chars = array("a", "b", "c", "d", "e", "f", "g", "h", "i", "j", "k", "l", "m", "n", "o", "p", "q", "r", "s", "t", "u", "v", "w", "x", "y", "z", "A", "B", "C", "D", "E", "F", "G", "H", "I", "J", "K", "L", "M", "N", "O", "P", "Q", "R", "S", "T", "U", "V", "W", "X", "Y", "Z", "0", "1", "2", "3", "4", "5", "6", "7", "8", "9");
	$pwd = "";
	for ($i = 0; $i < $len; $i++) {
		$pwd .=$chars[rand(0, 62)];
	}
	return $pwd;
}

/**
 * This function will truncate the string.
 * @param	string.
 * @return	string.
 * @author	Anish Sharma
 */
function truncateStr($str, $max = 25, $holder = " ...") {
	if (strlen($str) > $max) {
		return trim(substr($str, 0, $max)) . $holder;
	} else {
		return $str;
	}
}

/**
 * This function will return all the states.
 * @param	string.
 * @return	string.
 * @author	Anish Sharma
 */
function stateList($stateId = '', $db = '') {
	$arrString = '';
	if (!is_object($db)) {
		makeDbConnection($db);
	}
	$query = "SELECT sId,sName,sCid FROM " . TABLESTATES . " WHERE status=1";
	$Res = $db->execQry($query);
	$Rows = $db->rowCount($Res);
	if ($Rows > 0) {
		while ($rowData = $db->fetchObj($Res)) {
			$selected = ($rowData->stId == $serviceTypeId) ? 'selected="selected"' : '';
			$arrString.= '<option value="' . $rowData->sId . '" ' . $selected . '>' . firstUpper($rowData->sName) . '</option>';
		}
	}
	return $arrString;
}

/**
 * This function will return all the branches.
 * @param	string.
 * @return	string.
 * @author	Anish Sharma
 */
function branchList($bId = '', $db = '') {
	$arrString = '';
	if (!is_object($db)) {
		makeDbConnection($db);
	}
	$query = "SELECT bId,bName,bCid FROM " . TABLEBRANCH . " WHERE status=1";
	$Res = $db->execQry($query);
	$Rows = $db->rowCount($Res);
	if ($Rows > 0) {
		while ($rowData = $db->fetchObj($Res)) {
			$selected = ($rowData->bId == $bId) ? 'selected="selected"' : '';
			$arrString.= '<option value="' . $rowData->bId . '" ' . $selected . '>' . firstUpper($rowData->bName) . '</option>';
		}
	}
	return $arrString;
}
/*  this function return all the payment plans add by kirti */

function paymentplanList($pId = '', $db = '') {
	$arrString = '';
	if (!is_object($db)) {
		makeDbConnection($db);
	}

	$query = "SELECT pId,pName,pBranchId  FROM " . TABLEPAYMENTPLANS . " WHERE status=1";
	$Res = $db->execQry($query);
	$Rows = $db->rowCount($Res);
	if ($Rows > 0) {
		while ($rowData = $db->fetchObj($Res)) {
			$selected = ($rowData->pId == $pId) ? 'selected="selected"' : '';
			$arrString.= '<option value="' . $rowData->pId . '" ' . $selected . '>' . firstUpper($rowData->pName) . '</option>';
		}
	}
	return $arrString;
}


/**
 * This function will return all the payment modes.
 * @param	string.
 * @return	string.
 * @author	Anish Sharma
 */
function paymentModeList($pmId = '', $db = '') {
	$arrString = '';
	if (!is_object($db)) {
		makeDbConnection($db);
	}
	$query = "SELECT pmId,pmName FROM " . TABLEPAYMENTMODE . " WHERE status=1";
	$Res = $db->execQry($query);
	$Rows = $db->rowCount($Res);
	if ($Rows > 0) {
		while ($rowData = $db->fetchObj($Res)) {
			$selected = ($rowData->pmId == $pmId) ? 'selected="selected"' : '';
			$arrString.= '<option value="' . $rowData->pmId . '" ' . $selected . '>' . $rowData->pmName . '</option>';
		}
	}
	return $arrString;
}

/**
 * This function will return all the advisors respective to the branch & service type.
 * @param	string.
 * @return	string.
 * @author	Anish Sharma
 */
function advisorList($adId = '', $stId = '', $brId = '', $db = '') {
	$arrString = '';
	if (!is_object($db)) {
		makeDbConnection($db);
	}
	$query = "SELECT adId,adName FROM " . TABLEADVISOR . " WHERE status=1 AND adBrId=" . $brId;
	if ($stId <> "") {
		$query.=" AND adStId=" . $stId;
	}

	$Res = $db->execQry($query);
	$Rows = $db->rowCount($Res);
	if ($Rows > 0) {
		while ($rowData = $db->fetchObj($Res)) {
			$selected = ($rowData->adId == $adId) ? 'selected="selected"' : '';
			$arrString.= '<option value="' . $rowData->adId . '" ' . $selected . '>' . $rowData->adName . '</option>';
		}
	}
	return $arrString;
}

/**
 * This function will return all the counsultancy types.
 * @param	string.
 * @return	string.
 * @author	Anish Sharma
 */
function counsultancyTypeList($ctId = '', $db = '') {
	$arrString = '';
	if (!is_object($db)) {
		makeDbConnection($db);
	}
	$query = "SELECT ctId,ctName FROM " . TABLECONSULTANCYTYPE . " WHERE status=1";
	$Res = $db->execQry($query);
	$Rows = $db->rowCount($Res);
	if ($Rows > 0) {
		while ($rowData = $db->fetchObj($Res)) { 
			$selected = ($rowData->ctId == $ctId) ? 'selected="selected"' : '';
			//$selected line uncomment by me
			$arrString.= '<option value="' . $rowData->ctId . '" ' . $selected . '>' . $rowData->ctName . '</option>';
		}
		return $arrString;
	}
}

/**
 * This function will return all the branches respective to the country id.
 * @param	string.
 * @return	string.
 * @author	Anish Sharma
 */
function branchListByCountry($cId = '', $bId = '', $db = '') {
	$arrString = '';
	if (!is_object($db)) {
		makeDbConnection($db);
	}
	$query = "SELECT bId,bName,bCid FROM " . TABLEBRANCH . " WHERE status=1";
	$Res = $db->execQry($query);
	$Rows = $db->rowCount($Res);
	if ($Rows > 0) {
		//	print_r($bId);
		if (!is_array($bId)) {
			$bid = explode(',', $bId);
		} else {
			$bid = $bId;
		}
		while ($rowData = $db->fetchObj($Res)) {
			$selected = (in_array($rowData->bId, $bid)) ? 'selected="selected"' : '';
			$arrString.= '<option value="' . $rowData->bId . '" ' . $selected . '>' . firstUpper($rowData->bName) . '</option>';
		}
	}
	return $arrString;
}

/**
 * This function will return all the branches according to the login.
 * @param	string.
 * @return	string.
 * @author	Anish Sharma
 */
function branchListByLogin($bUsrId = '', $srBr = '', $flag = '', $db = '') {
	$arrString = '';
	if (!is_object($db)) {
		makeDbConnection($db);
	}

	$sqlUsrType = "SELECT bUserTypeId AS id FROM " . TABLEBRANCH . " WHERE bId = {$bUsrId}";
	$resUsrType = $db->execQry($sqlUsrType);
	$rowUsrType = $db->rowCount($resUsrType);
	if ($rowUsrType > 0) {
		$row = $db->fetchObj($resUsrType);
		if ($row->id == 2) {
			$where = ' bId=' . $srBr . ' AND ';
		} else {
			$where = '';
			if ($flag != 1) {
				$arrString .= '<option value="all" selected>All Branches</option>';
			} else {
				$arrString .= "";
			}
		}
	}

	$query = "SELECT bId,bName FROM " . TABLEBRANCH . " WHERE " . $where . " status=1 AND bUserTypeId=2 ORDER BY bName";
	$Res = $db->execQry($query);
	$Rows = $db->rowCount($Res);
	if ($Rows > 0) {
		while ($rowData = $db->fetchObj($Res)) {
			$selected = ($rowData->bId == $srBr) ? 'selected="selected"' : '';
			$arrString.= '<option value="' . $rowData->bId . '" ' . $selected . '>' . firstUpper($rowData->bName) . '</option>';
		}
	}
	return $arrString;
}

/**
 * This function will return all the advisors respective to the branch & service type.
 * @param	string.
 * @return	string.
 * @author	Anish Sharma
 */
function advisorListByLogin($bUsrId = '', $brId = '', $db = '') {
	$arrString = '';
	if (!is_object($db)) {
		makeDbConnection($db);
	}

	$sqlUsrType = "SELECT bUserTypeId AS id FROM " . TABLEBRANCH . " WHERE bId = {$bUsrId}";
	$resUsrType = $db->execQry($sqlUsrType);
	$rowUsrType = $db->rowCount($resUsrType);
	if ($rowUsrType > 0) {
		$row = $db->fetchObj($resUsrType);
		if ($row->id == 2) {
			$where = " AND adBrId = {$bUsrId} ";
		} else {
			$where = '';
		}
	}

	$query = "SELECT adId,adName,adStId FROM " . TABLEADVISOR . " WHERE status=1 {$where} ORDER BY adStId";
	$Res = $db->execQry($query);
	$Rows = $db->rowCount($Res);
	if ($Rows > 0) {
		while ($rowData = $db->fetchObj($Res)) {
			if ($rowData->adStId == 1) {
				//$st    = '(IMMI)';
				$style = 'style="color:#FE6602"';
			} else {
				//$st    = '(SA)';
				$style = 'style="color:#00923F"';
			}
			$selected = ($rowData->adId == $brId) ? 'selected="selected"' : '';
			$arrString.= '<option value="' . $rowData->adId . '" ' . $style . ' ' . $selected . '>' . $rowData->adName . '</option>';
		}
	}
	return $arrString;
}

/**
 * This function will return all the installments respective to the country id.
 * @param	string.
 * @return	string.
 * @author	Anish Sharma
 */
function installMentByCountry($cId = '', $bId = '', $db = '') {
	$arrString = '';
	if (!is_object($db)) {
		makeDbConnection($db);
	}
	$query = "SELECT iId,iName,iCountryId FROM " . TABLEINSTALLMENT . " I LEFT JOIN " . TABLECOUNTRY . " C ON(cId=iCountryId) WHERE iCountryId= " . $cId . " AND C.status=1 AND I.status=1";
	$Res = $db->execQry($query);
	$Rows = $db->rowCount($Res);
	if ($Rows > 0) {
		if (!is_array($bId)) {
			$bid = explode(',', $bId);
		} else {
			$bid = $bId;
		}
		while ($rowData = $db->fetchObj($Res)) {
			$selected = (in_array($rowData->iId, $bid)) ? 'selected="selected"' : '';
			$arrString.= '<option value="' . $rowData->iId . '" ' . $selected . '>' . $rowData->iName . '</option>';
		}
	}
	return $arrString;
}

/**
 * This function will return all the installments respective to the country id.
 * @param	string.
 * @return	string.
 * @author	Anish Sharma
 */
function installMents($cId = '', $stId = '', $db = '') {
	$arrString = '';
	if (!is_object($db)) {
		makeDbConnection($db);
	}
	$query = ' SELECT iId,iName,iCountryId FROM ' . TABLEINSTALLMENT . ' WHERE iCountryId= ' . $cId . ' AND iServTypeId = ' . $stId . ' AND status=1';
	$Res = $db->execQry($query);
	$Rows = $db->rowCount($Res);
	if ($Rows > 0) {
		while ($rowData = $db->fetchObj($Res)) {
			$arrString.= '<option value="' . $rowData->iId . '">' . $rowData->iName . '</option>';
		}
	}
	return $arrString;
}

/**
 * This function will return all the states respective to the country.
 * @param	string.
 * @return	string.
 * @author	Anish Sharma
 */
function stateListByCountry($sCid = '', $sId = '', $db = '') {
	$arrString = '';
	if (!is_object($db)) {
		makeDbConnection($db);
	}
	$query = "SELECT sName,sId FROM " . TABLESTATES . " WHERE sCid = " . $sCid . " AND status=1 ORDER BY sName";
	$Res = $db->execQry($query);
	$Rows = $db->rowCount($Res);
	if ($Rows > 0) {
		while ($rowData = $db->fetchObj($Res)) {
			$selected = ($rowData->sId == $sId) ? 'selected="selected"' : '';
			$arrString.= '<option value="' . $rowData->sId . '" ' . $selected . '>' . $rowData->sName . '</option>';
		}
	}
	return $arrString;
}

/**
 * This function will return all the states respective to the country.
 * @param	string.
 * @return	string.
 * @author	Anish Sharma
 */
function statesList($sCid = '', $sId = '', $db = '') {
	$arrString = '';
	if (!is_object($db)) {
		makeDbConnection($db);
	}
	if ($sCid == '76') {
		$query = "SELECT sName,sId FROM " . TABLESTATES . " WHERE sCid = " . $sCid . " AND status=1 ORDER BY sName";
		$Res = $db->execQry($query);
		$Rows = $db->rowCount($Res);
		if ($Rows > 0) {
			while ($rowData = $db->fetchObj($Res)) {
				$selected = ($rowData->sId == $sId || $rowData->sName == $sId) ? 'selected="selected"' : '';
				$arrString.= '<option value="' . $rowData->sId . '" ' . $selected . '>' . $rowData->sName . '</option>';
			}
		}
	}
	return $arrString;
}

/**
 * This function will return all the states respective to the country.
 * @param	string.
 * @return	string.
 * @author	Anish Sharma
 */
function serviceCountry($scId = '', $db = '') {
	$arrString = '';
	if (!is_object($db)) {
		makeDbConnection($db);
	}
	$query = "SELECT cId, cName, scServTypeId FROM " . TABLESERVICECOUNTRY . " LEFT OUTER JOIN " . TABLECOUNTRY . "  ON (cId=scCountryId) GROUP BY cId ORDER BY scServTypeId";
	$Res = $db->execQry($query);
	$Rows = $db->rowCount($Res);
	if ($Rows > 0) {
		while ($rowData = $db->fetchObj($Res)) {
			$style = ($rowData->scServTypeId == 1) ? 'style="color:#FE6602"' : 'style="color:#00923F"';
			$selected = ($rowData->cId == $scId) ? 'selected="selected"' : '';
			$arrString.= '<option value="' . $rowData->cId . '" ' . $selected . ' ' . $style . '>' . $rowData->cName . '</option>';
		}
	}
	return $arrString;
}

/**
 * This function will return all the payment plans respective to the branch.
 * @param	string.
 * @return	string.
 * @author	Anish Sharma
 */
function paymentPlanByBranch($bId = '', $db = '') {
	$arrString = '';
	if (!is_object($db)) {
		makeDbConnection($db);
	}
	$query = "SELECT pName,pId FROM " . TABLEPAYMENTPLANS . " WHERE FIND_IN_SET('" . $bId . "',pBranchId) AND status=1";
	$Res = $db->execQry($query);
	$Rows = $db->rowCount($Res);
	if ($Rows > 0) {
		while ($rowData = $db->fetchObj($Res)) {
			$selected = ($rowData->pId == $bId) ? 'selected="selected"' : '';
			$arrString.= '<option value="' . $rowData->pId . '" ' . $selected . '>' . $rowData->pName . '</option>';
		}
	}
	return $arrString;
}

/**
 * This function will return all the payment plans by login.
 * @param	string.
 * @return	string.
 * @author	Anish Sharma
 */
function pPlanByLogin($bUsrId = '', $pId = '', $db = '') {
	$arrString = '';
	if (!is_object($db)) {
		makeDbConnection($db);
	}

	$sqlUsrType = "SELECT bUserTypeId AS id FROM " . TABLEBRANCH . " WHERE bId = {$bUsrId}";
	$resUsrType = $db->execQry($sqlUsrType);
	$rowUsrType = $db->rowCount($resUsrType);
	if ($rowUsrType > 0) {
		$row = $db->fetchObj($resUsrType);
		if ($row->id == 2) {
			$where = " AND FIND_IN_SET('" . $bUsrId . "',pBranchId) ";
		} else {
			$where = '';
		}
	}

	$query = "SELECT pName,pId FROM " . TABLEPAYMENTPLANS . " WHERE status=1 {$where}";
	$Res = $db->execQry($query);
	$Rows = $db->rowCount($Res);

	if ($Rows > 0) {
		while ($rowData = $db->fetchObj($Res)) {
			$selected = ($rowData->pId == $pId) ? 'selected="selected"' : '';
			$arrString.= '<option value="' . $rowData->pId . '" ' . $selected . '>' . $rowData->pName . '</option>';
		}
	}
	return $arrString;
}

/**
 * This function will return all the countries respective to the servicetype.
 * @param	string.
 * @return	string.
 * @author	Anish Sharma
 */
function countryListByService($sCid = '', $sId = '', $db = '') {
	$arrString = '';
	if (!is_object($db)) {
		makeDbConnection($db);
	}
	$query = "SELECT cId,cName,cCode FROM " . TABLECOUNTRY . " C LEFT JOIN " . TABLESERVICECOUNTRY . " S ON (cId = scCountryId) WHERE scServTypeId = " . $sId . " AND C.status=1";
	$Res = $db->execQry($query);
	$Rows = $db->rowCount($Res);
	if ($Rows > 0) {
		while ($rowData = $db->fetchObj($Res)) {
			$selected = ($rowData->cId == $sCid) ? 'selected="selected"' : '';
			$arrString.= '<option value="' . $rowData->cId . '" ' . $selected . '>' . $rowData->cName . '</option>';
		}
	}
	return $arrString;
}

/**
 * This function will return the state's name.
 * @param	string.
 * @return	string.
 * @author	Anish Sharma
 */
function getStateName($stateId = '', $db = '') {
	$sName = '';
	if (!is_object($db)) {
		makeDbConnection($db);
	}
	$query = "SELECT sName FROM " . TABLESTATES . " WHERE sId='{$stateId}'";
	$Res = $db->execQry($query);
	$Rows = $db->rowCount($Res);
	if ($Rows > 0) {
		$rowData = $db->fetchObj($Res);
		$sName = $rowData->sName;
	}
	return $sName;
}

/**
 * This function will return the state code.
 * @param	string.
 * @return	string.
 * @author	Anish Sharma
 */
//function getStateCode($stateId='', $bName='', $db=''){
function getStateCode($stateId = '', $db = '') {
	$sName = '';
	if (!is_object($db)) {
		makeDbConnection($db);
	}
	//$query = "SELECT bScode,bCode FROM ".TABLEBRANCH." WHERE bSid={$stateId} AND bName = '{$bName}'";
	$query = "SELECT bScode,bCode FROM " . TABLEBRANCH . " WHERE bId=" . $stateId;
	$Res = $db->execQry($query);
	$Rows = $db->rowCount($Res);
	$rowData = $db->fetchObj($Res);
	$sName = $rowData->bScode . $rowData->bCode;
	return $sName;
}

/** [ADDED ON 13th Sept 2010]
 * This function will maintain the MONTH & YEAR for retainer agreement number.
 * @param	Client Unique ID.
 * @return	month-year.
 * @author	Anish Sharma
 */
function getMonYrForRa($raNo = '', $bId = '', $email = '', $db = '') {
	$monYr = '';
	if (!is_object($db)) {
		makeDbConnection($db);
	}

	$checkForMultiRcpts = $db->execQry("SELECT COUNT(clId) AS total FROM " . TABLECLIENT . " WHERE clRetainerAggNo = " . $raNo . " AND clReceiptIssuingBranchId=" . $bId . " AND clEmail = '" . $email . "'");
	$chkCount = $db->fetchObj($checkForMultiRcpts);
	if ($chkCount->total) {
		$sqlGetMonYrForRa = $db->execQry("SELECT DATE_FORMAT(clCreateDate,'%m') AS raMonth, DATE_FORMAT(clCreateDate,'%y') AS raYear FROM " . TABLECLIENT . " WHERE
clRetainerAggNo = " . $raNo . " AND clReceiptIssuingBranchId=" . $bId . " AND clEmail = '" . $email . "' ORDER BY clCreateDate ASC LIMIT 1");
		$resGetMonYrForRa = $db->fetchObj($sqlGetMonYrForRa);
		$monYr = $resGetMonYrForRa->raMonth . $resGetMonYrForRa->raYear;
	} else {
		$monYr = '';
	}
	return $monYr;
}

/**
 * This function will return the prefix code for Client Unique ID.
 * @param	string.
 * @return	string.
 * @author	Anish Sharma
 */
function getPreCodeForRaNo($stId = '', $bId = '', $scId = '', $db = '') {
	$preCode = '';
	if (!is_object($db)) {
		makeDbConnection($db);
	}
	$query = "SELECT stCode,bCode FROM " . TABLESERVICETYPE . ',' . TABLEBRANCH . " WHERE stId={$stId} AND bId = {$bId}";
	$Res = $db->execQry($query);
	$Rows = $db->rowCount($Res);
	$rowData = $db->fetchObj($Res);
	$currCode = explode(',', getCurrCode($scId));
	$preCode = $currCode[0] . $rowData->stCode . $rowData->bCode;
	return $preCode;
}

/**
 * This function will return the prefix code for receipt number.
 * @param	string.
 * @return	string.
 * @author	Anish Sharma
 */
function getPreCodeForRno($bId = '', $db = '') {
	$preCode = '';
	if (!is_object($db)) {
		makeDbConnection($db);
	}

	$query = "SELECT bScode, bCode, bCid FROM tbl_branch WHERE bId = '{$bId}' ";
	$Res = $db->execQry($query);
	$Rows = $db->rowCount($Res);
	$rowData = $db->fetchObj($Res);
	$preCode = $rowData->bScode . $rowData->bCode;
	return $preCode . ',' . $rowData->bCid;
}

/**
 * This function will return the service type name.
 * @param	string.
 * @return	string.
 * @author	Anish Sharma
 */
function getServiceTypeName($stId = '', $db = '') {
	$stName = '';
	if (!is_object($db)) {
		makeDbConnection($db);
	}
	$query = "SELECT stName FROM " . TABLESERVICETYPE . " WHERE stId={$stId}";
	$Res = $db->execQry($query);
	$Rows = $db->rowCount($Res);
	$rowData = $db->fetchObj($Res);
	$stName = $rowData->stName;
	return $stName;
}

/**
 * This function will return the payment plan's name.
 * @param	string.
 * @return	string.
 * @author	Anish Sharma
 */
function getPayPlanName($pId = '', $db = '') {
	$pName = '';
	if (!is_object($db)) {
		makeDbConnection($db);
	}
	$query = "SELECT pName FROM " . TABLEPAYMENTPLANS . " WHERE pId={$pId}";
	$Res = $db->execQry($query);
	$Rows = $db->rowCount($Res);
	$rowData = $db->fetchObj($Res);
	if ($Rows > 0) {
		$pName = $rowData->pName;
	}
	return $pName;
}

/**
 * This function will return the payment plan's amount.
 * @param	string.
 * @return	string.
 * @author	Anish Sharma
 */
function getPayPlanAmt($pId = '', $flag = '', $db = '', $country_id = '') {
	$pAmt = '';
	$curr = '';
	if (!is_object($db)) {
		makeDbConnection($db);
	}
	$query = "SELECT pAmt,pCurrId FROM " . TABLEPAYMENTPLANS . " WHERE pId={$pId}";
	$Res = $db->execQry($query);
	$Rows = $db->rowCount($Res);
	$rowData = $db->fetchObj($Res);
	if ($country_id == '') {
		$curr = explode(',', getCurrCode($_SESSION['session_countryId']));
	} else {
		$curr = explode(',', getCurrCode($country_id));
	}
	if ($Rows > 0) {
		if ($flag == 0) {
			$pAmt = $curr[0] . '&nbsp;' . $rowData->pAmt;
		} else {
			$pAmt = $rowData->pAmt;
		}
	}
	return $pAmt;
}

/**
 * This function will return the payment mode's name.
 * @param	string.
 * @return	string.
 * @author	Anish Sharma
 */
function getPayMode($pmId = '', $db = '') {
	$pmName = '';
	if (!is_object($db)) {
		makeDbConnection($db);
	}
	$query = "SELECT pmName FROM " . TABLEPAYMENTMODE . " WHERE pmId={$pmId}";
	$Res = $db->execQry($query);
	$Rows = $db->rowCount($Res);
	if ($Rows > 0) {
		$rowData = $db->fetchObj($Res);
		$pmName = $rowData->pmName;
	}
	return $pmName;
}

/**
 * This function will return payment plans according to service type and service country
 * @param string
 * @return string
 * @author Anju Kansal
 */
function paymentPlanByTypeCoun($servTypeId = '', $servCounId = '', $planId = '', $db = '') {
	$plan = "";
	if (!is_object($db)) {
		makeDbConnection($db);
	}
	if (($servTypeId != '') && ($servCounId != '')) {
		$sqlPlan = "SELECT pName,pId FROM tbl_paymentplans WHERE status=1  AND pServTypeId={$servTypeId} AND pServCid={$servCounId}";
		//$result = mysqli_query($db,$sqlPlan);
         $result = $db->execQry($sqlPlan);
		if (mysqli_num_rows($result) > 0) {
			$plan .= "<option value=''>-Select Payment Plan-</option>";
			while ($row = mysqli_fetch_array($result)) {
				$selected = ($row['pId'] == $planId) ? " selected='selected'" : "";
				$plan .= "<option value=\"{$row['pId']}\" {$selected}>{$row['pName']}</option>";
			}
			return $plan;
		}
		if (mysqli_num_rows($result) == 0) {
			$plan = '';
			return $plan;
		}
	} else {
		return 0;
	}
}

function paymentPlanByTypeCounBranch($servTypeId = '',$clReceiptIssuingBranchId = '', $servCounId = '', $planId = '') {
	$plan = "";
	
	if (($servTypeId != '') && ($servCounId != '')) {
		$sqlPlan = "SELECT pName,pId FROM tbl_paymentplans WHERE status=1  AND pServTypeId={$servTypeId} AND pServCid={$servCounId} AND pBranchId LIKE '%{$clReceiptIssuingBranchId}%'";
		$result = mysqli_query($sqlPlan);

		if (mysqli_num_rows($result) > 0) {
			$plan .= "<option value=''>-Select Payment Plan-</option>";
			while ($row = mysqli_fetch_array($result)) {
				$selected = ($row['pId'] == $planId) ? " selected='selected'" : "";
				$plan .= "<option value=\"{$row['pId']}\" {$selected}>{$row['pName']}</option>";
			}
			//echo $plan;
			return $plan;
		}
		if (mysqli_num_rows($result) == 0) {
			$plan = '';
			return $plan;
		}
	} else {
		return 0;
	}
}

/**
 * This function will generate a unique random number.
 * @param	value, by default its 6.
 * @return	number.
 * @usage	rNumber(); OR rNumber(7);
 * @author	Anish Sharma
 */
function rNumber($n = 6) {
	//return substr(md5(uniqid(rand(0,pow(10, $n)),true)),0, 8);
	return substr(uniqid(rand(0, pow(10, $n)), true), 0, $n);
}

/**
 * This function will generate a new recipt number for the current financial year, respective to the logged in branch. (1st April - 31st March of the ongoing financial year)
 * @param	-
 * @return auto generated receipt number ( format : BRANCHCODE-AREACODE-CURRENTYEAR-AUTOGENNUMBER e.g: HRY-009-08-001)06-12-09-001 [PREVIOUS CONCEPT till 5th MAY 2010]
 * ***********************************************************************************************************************************************************************
 * @return auto generated receipt number ( format : BRANCHCODE-AREACODE-CURRENTYEAR-CURRENTMONTH-AUTOGENNUMBER e.g: HRY-009-08-12-001)06-12-09-05-001 [CHANGED THE SERIES & * ADDED MONTH IN THE AUTO GENERATED NO. which will be displayed from 06th MAY 2010 -- this change was done due to a bug found in the system for the same receipt no. in *   the current financial year]
 * ************************************************************************************************************************************************************************
 * @author	Anish Sharma
 */
function genReceiptNo($db = '') {
	// set the default timezone to use. Available since PHP 5.1
	date_default_timezone_set("Asia/Calcutta");

	$autoReceiptNo = '';
	$year = date('Y');
	$month = date('n');
	$sessBid = $_SESSION['session_userId'];
	//$prefixCode	   = getStateCode($sessBid).date('y'); [PREVIOUS CONCEPT - for more details see my comments above]
	//$prefixCode = 'MP'.getStateCode($sessBid) . date('y') . date('m'); // [NEW CONCEPT ADDED ON 5th MAY 2010]
	$prefixCode = getStateCode($sessBid) . date('y') . date('m'); // [NEW CONCEPT ADDED ON 30th March 2017]

	if ($month > 3) {
		$date1 = $year . '-03-31';
		$date2 = ($year + 1) . '-04-01';
	} else {
		$date1 = ($year - 1) . '-03-31';
		$date2 = $year . '-04-01';
	}

	if (!is_object($db)) {
		makeDbConnection($db);
	}
	$qrySel = "SELECT IFNULL(MAX(clReceiptNo),0)+1 AS rNo FROM " . TABLECLIENT . " WHERE DATE_FORMAT(clCreateDate,'%Y-%m-%d') > DATE('{$date1}') AND DATE_FORMAT(clCreateDate,'%Y-%m-%d') < DATE('{$date2}')  AND clReceiptIssuingBranchId = {$sessBid} ";
	$resSel = $db->execQry($qrySel);
	$rowSel = $db->fetchObj($resSel);

	$autoReceiptNo = $prefixCode . str_pad($rowSel->rNo, 3, "0", STR_PAD_LEFT);

	return array($autoReceiptNo, $rowSel->rNo);
}

/**
 * This function will generate a new Client Unique ID and update the `clRetainerAggNo` field in tbl_client
 * @param	posted: service type id, service country id, last inserted id
 * @return	auto generated Client Unique ID ( format : SERVICECOUNTRYCODE-SERVICETYPECODE-BRANCHID-MONTHOFISSUE-YEAROFISSUE-INCREMENTEDNUMBER e.g. CAN-003-009-07-08-0001)
 * @author	Anish Sharma
 * * */
function genRaNo($stId = '', $scId = '', $incId = '', $db = '') {
	$autoRaNo = '';
	$bId = $_SESSION['session_userId'];

	if (!is_object($db)) {
		makeDbConnection($db);
	}

	$qrySel = "SELECT IFNULL( MAX( clRetainerAggNo ) , 0 ) +1 AS raNo
				FROM " . TABLECLIENT . "
				WHERE clServCountryId =" . $scId . "
				AND clServTypeId =" . $stId . "
				AND clReceiptIssuingBranchId=" . $bId;

	$resSel = $db->execQry($qrySel);
	$rowCnt = $db->rowCount($resSel);
	$rowSel = $db->fetchObj($resSel);

	$qryUp = "UPDATE " . TABLECLIENT . " SET clRetainerAggNo = '" . $rowSel->raNo . "' WHERE clId=" . $incId;
	$resUp = $db->execQry($qryUp);
}

/**
 * This function will generate a new installment number and update the `clInstNo` field in tbl_client
 * @param	posted: service type id, service country id, last inserted id
 * @return	auto generated installment number
 * @author	Anish Sharma
 * * */
function genInstNo($stId = '', $scId = '', $incId = '', $email = '', $name = '', $db = '') {
	$bId = $_SESSION['session_userId'];
	$clInstNo = '';
	if (!is_object($db)) {
		makeDbConnection($db);
	}
	$qrySel = "SELECT MAX(clInstNo) AS clInstNo FROM " . TABLECLIENT . " WHERE clReceiptIssuingBranchId =" . $bId . " AND clServCountryId =" . $scId . " AND clServTypeId =" . $stId . " AND clEmail='" . $email . "' AND CONCAT(clFirstName,clMiddleName,clLastName) = '" . $name . "'";

	//$qrySel = "SELECT clInstNo FROM ".TABLECLIENT." WHERE clReceiptIssuingBranchId =".$bId." AND clServCountryId =".$scId." AND clServTypeId =".$stId." AND clEmail='".$email."' ORDER BY clInstNo DESC LIMIT 0,1";

	$resSel = $db->execQry($qrySel);
	$rowCnt = $db->rowCount($resSel);
	$rowSel = $db->fetchObj($resSel);
	$insNo = $rowSel->clInstNo;

	if ($rowCnt == 0) {
		$qryUp = "UPDATE " . TABLECLIENT . " SET clInstNo = 1 WHERE clId =" . $incId;
	} else {
		$qryUp = "UPDATE " . TABLECLIENT . " SET clInstNo = " . ($insNo + 1) . " WHERE clId =" . $incId;
	}
	$resUp = $db->execQry($qryUp);
}

function mysqli_now() {
	if ($_SERVER['SERVER_NAME'] === 'localhost') {
		return 'NOW()';
	} else {
		return 'NOW()';
		//return 'DATE_ADD(NOW(),INTERVAL 12.30 HOUR_MINUTE)';
	}
}

/* Country Zone : Time Zone Name
  -12 : Dateline Standard
  -11 : Samoa Standard Time
  -10 : Hawaiian Standard Time
  -8 : Pacific Standard Time
  -7 : Mexican Standard Time, Mountain Standard Time
  -6 : Central Standard Time, Mexico Standard Time
  -5 : Eastern Standard Time Eastern Time, SA Pacific Standard Time
  -4 : Atlantic Standard Time, SA Western Standard Time, Pacific SA Standard Time
  -3.5 : Newfoundland Standard Time
  -3 : SA Eastern Standard Time, E. South America Standard Time
  -2 : Mid:Atlantic Standard Time
  -1 : Azores Standard Time, Cape Verde Standard Time
  0 : Universal Coordinated Time, Greenwich Mean Time
  1 : Romance Standard Time, Central Africa Standard Time, Central European Standard Time
  2 : Egypt Standard Time, South Africa Standard Time, E. Europe Standard Time, FLE Standard Time, GTB Standard Time
  3 : Arab Standard Time, E. Africa Standard Time, Arabic Standard Time, Russian Standard Time
  3.5 : Iran Standard Time
  4 : Arabian Standard Time, Caucasus Standard Time, Afghanistan Standard Time
  5 : West Asia Standard Time
  5.5 : India Standard Time
  5.75 : Nepal Standard Time
  6 : Central Asia Standard Time
  6.5 : Myanmar Standard Time
  7 : SE Asia Standard Time, North Asia Standard Time
  8 : China Standard Time, W. Australia Standard Time, Singapore Standard Time, Taipei Standard Time, North Asia East Standard Time
  9 : Tokyo Standard Time, Korea Standard Time, Yakutsk Standard Time
  9.5 : AUS Central Standard Time, Cen. Australia Standard Time
  10 : AUS Eastern Standard Time, E. Australia Standard Time
  West Pacific Standard Time, Tasmania Standard Time, Vladivostok Standard Time
  11 : Central Pacific Standard Time
  12 : Fiji Standard Time, New Zealand Standard Time
  13 : Tonga Standard Time

 * How to use
  $layout =
  Same function as date : http://uk2.php.net/manual/en/function.date.php
  $countryzone =
  Country Zone from Above Eg: 0 ,for Greenwich Mean Time
  $daylightsaving =
  Set true if the Country has daylight saving it will auto change.
  Set false if the Country dose not have daylight saving or wish to it Disabled.
  (About Daylight Saving go here : http://www.timeanddate.com/time/aboutdst.html)
  Call Function:
  zonedate($layout, $countryzone, $daylightsaving);

  E.g.
  If GMT = Friday 25th of August 2006 10:23:17 AM
  When Function called:
  // West Asia Standard Time (Country Uses daylight saving)
  echo zonedate("l dS \of F Y h:i:s A", 5, true);
  //Output : Friday 25th of August 2006 03:23:17 PM
 */

function zoneDate($layout, $countryzone, $daylightsaving) {
	if ($daylightsaving) {
		$daylight_saving = date('I');
		if ($daylight_saving) {
			$zone = 3600 * ($countryzone + 1);
		}
	} else {
		if ($countryzone >> 0) {
			$zone = 3600 * $countryzone;
		} else {
			$zone = 0;
		}
	}
	$date = gmdate($layout, time() + $zone);
	return $date;
}
/*
//Service tax 14% applicable from 1st june2015 previous it was 12.36%  included
//Service tax 14% to 14.5% included revised from 15 nov2015
function calculateTax($amt) {
	//$stAmt=round($amt/112.36 * 100, 2);
	//$stAmtr=round($amt/112.36 * 100, 0);
	//$stAmt=round($amt/114 * 100, 2);
	//$stAmtr=round($amt/114 * 100, 0);
	$stAmt=round($amt/114.5 * 100, 2);
	$stAmtr=round($amt/114.5 * 100, 0);
	if($stAmtr > $stAmt){
		$stAmt=$stAmtr-1;
	}
	else{
		$stAmt=$stAmtr;
	}
	
	return $stAmt;
}

*/


//Service tax 12.36% to 14% included revised from 1st june 2015
//Service tax 14% to 14.5% included revised from 15 nov2015
//Service tax 14.5% to 15% included revised from 1st June 2016
//Service tax 15% to 18% GST included revised from 1st Jul 2017
function calculateTax($amt) {
	/*$stAmt=round($amt/112.36 * 100, 2);
	$stAmtr=round($amt/112.36 * 100, 0);*/
	/*$stAmt=round($amt/114 * 100, 2);
	$stAmtr=round($amt/114 * 100, 0);*/
	/*$stAmt=round($amt/114.5 * 100, 2);
	$stAmtr=round($amt/114.5 * 100, 0);*/
	//$stAmt=round($amt/115 * 100, 2);
	//$stAmtr=round($amt/115 * 100, 0);
	$stAmt=round($amt/118 * 100, 2);
	$stAmtr=round($amt/118 * 100, 0);
	
	
	
	if($stAmtr > $stAmt){
		$stAmt=$stAmtr-1;
	}
	else{
		$stAmt=$stAmtr;
	}
	
	return $stAmt;
}

 

/**
 * This function will return the payment mode's name.
 * @param	string.
 * @return	string.
 * @author	Anish Sharma
 */
function getCompletePastDiscounts($rag,$bId,$ct,$st,$sc,$db ='') {
	$pmName = '';
	if (!is_object($db)) {
		makeDbConnection($db);
	}
	$query = "SELECT  SUM( pdDiscount ) AS totalDiscount
FROM tbl_client TCIN
LEFT OUTER JOIN tbl_paydetails TPIN ON ( clId = pdClId )
WHERE clRetainerAggNo LIKE '".$rag."'
AND clReceiptIssuingBranchId = ".$bId."
AND clCtTypeId =".$ct."
AND clServTypeId =".$st."
AND clServCountryId =".$sc."
GROUP BY clServCountryId";
	$Res = $db->execQry($query);
	$Rows = $db->rowCount($Res);
	if ($Rows > 0) {
		$rowData = $db->fetchObj($Res);
		$totalDiscount = $rowData->totalDiscount;
	}
	return $totalDiscount;
}
?>
